.. _visualizations:

Visualizations
==============

Oríon provides several plotting helpers to support visual analysis of hyperparameter optimization
runs. These tools will help you:

- Examine the optimization curve
  (:ref:`regret plot <sphx_glr_auto_examples_plot_1_regret.py>`),
- Find trends for best hyperparemeters in search spaces with many dimensions
  (:ref:`parallel coordinates <sphx_glr_auto_examples_plot_2_parallel_coordinates.py>`)
- Assess which hyperparameters were most important globally
  (:ref:`local parameter importance <sphx_glr_auto_examples_plot_3_lpi.py>`)
- Dissect the search space in slices to observe dependencies across dimensions
  (:ref:`partial dependencies <sphx_glr_auto_examples_plot_4_partial_dependencies.py>`).

Examples
--------

Detailed examples of the different type of visualizations, how to use and interpret them.
